==> google-cloud-functions-1.8.0.tar.gz: google-cloud-functions-1.8.0/google/cloud/functions/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from google.cloud.functions_v1.services.cloud_functions_service.async_client import (
    CloudFunctionsServiceAsyncClient,
)
from google.cloud.functions_v1.services.cloud_functions_service.client import (
    CloudFunctionsServiceClient,
)
from google.cloud.functions_v1.types.functions import (
    CallFunctionRequest,
    CallFunctionResponse,
    CloudFunction,
    CloudFunctionStatus,
    CreateFunctionRequest,
    DeleteFunctionRequest,
    EventTrigger,
    FailurePolicy,
    GenerateDownloadUrlRequest,
    GenerateDownloadUrlResponse,
    GenerateUploadUrlRequest,
    GenerateUploadUrlResponse,
    GetFunctionRequest,
    HttpsTrigger,
    ListFunctionsRequest,
    ListFunctionsResponse,
    SecretEnvVar,
    SecretVolume,
    SourceRepository,
    UpdateFunctionRequest,
)
from google.cloud.functions_v1.types.operations import (
    OperationMetadataV1,
    OperationType,
)

__all__ = (
    "CloudFunctionsServiceClient",
    "CloudFunctionsServiceAsyncClient",
    "CallFunctionRequest",
    "CallFunctionResponse",
    "CloudFunction",
    "CreateFunctionRequest",
    "DeleteFunctionRequest",
    "EventTrigger",
    "FailurePolicy",
    "GenerateDownloadUrlRequest",
    "GenerateDownloadUrlResponse",
    "GenerateUploadUrlRequest",
    "GenerateUploadUrlResponse",
    "GetFunctionRequest",
    "HttpsTrigger",
    "ListFunctionsRequest",
    "ListFunctionsResponse",
    "SecretEnvVar",
    "SecretVolume",
    "SourceRepository",
    "UpdateFunctionRequest",
    "CloudFunctionStatus",
    "OperationMetadataV1",
    "OperationType",
)

==> google-cloud-functions-1.10.0.tar.gz: google-cloud-functions-1.10.0/google/cloud/functions/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from google.cloud.functions import gapic_version as package_version

__version__ = package_version.__version__


from google.cloud.functions_v1.services.cloud_functions_service.async_client import (
    CloudFunctionsServiceAsyncClient,
)
from google.cloud.functions_v1.services.cloud_functions_service.client import (
    CloudFunctionsServiceClient,
)
from google.cloud.functions_v1.types.functions import (
    CallFunctionRequest,
    CallFunctionResponse,
    CloudFunction,
    CloudFunctionStatus,
    CreateFunctionRequest,
    DeleteFunctionRequest,
    EventTrigger,
    FailurePolicy,
    GenerateDownloadUrlRequest,
    GenerateDownloadUrlResponse,
    GenerateUploadUrlRequest,
    GenerateUploadUrlResponse,
    GetFunctionRequest,
    HttpsTrigger,
    ListFunctionsRequest,
    ListFunctionsResponse,
    SecretEnvVar,
    SecretVolume,
    SourceRepository,
    UpdateFunctionRequest,
)
from google.cloud.functions_v1.types.operations import (
    OperationMetadataV1,
    OperationType,
)

__all__ = (
    "CloudFunctionsServiceClient",
    "CloudFunctionsServiceAsyncClient",
    "CallFunctionRequest",
    "CallFunctionResponse",
    "CloudFunction",
    "CreateFunctionRequest",
    "DeleteFunctionRequest",
    "EventTrigger",
    "FailurePolicy",
    "GenerateDownloadUrlRequest",
    "GenerateDownloadUrlResponse",
    "GenerateUploadUrlRequest",
    "GenerateUploadUrlResponse",
    "GetFunctionRequest",
    "HttpsTrigger",
    "ListFunctionsRequest",
    "ListFunctionsResponse",
    "SecretEnvVar",
    "SecretVolume",
    "SourceRepository",
    "UpdateFunctionRequest",
    "CloudFunctionStatus",
    "OperationMetadataV1",
    "OperationType",
)
